==> segatex-8.500.tar.gz: segatex-8.500/src/sesearch.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SESEARCH_H
#define SESEARCH_H

#include <qdialog.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qlabel.h> 
//added by intrajp
#include <QButtonGroup>
#include <QPushButton>
#include <QGroupBox>
#include <qradiobutton.h>
#include <QHBoxLayout>
#include <QVBoxLayout>


class QLayout;
class Q3TextEdit;
class QLineEdit;
class QPushButton;
class SesearchProcess;

class Sesearch: public QDialog 
{
	Q_OBJECT
public:
	Sesearch(QWidget *parent = 0, const char *name = 0);
	SesearchProcess *sesearch_process;
public slots:
signals:
protected:
private slots:
	void sesearch_button_clicked();
public:
private:
	QLabel *sesearchLabel;
	QLabel *sesearch2Label;
	QLabel *expressionLabel;
	QLabel *optionLabel;
	QLabel *rule_typesLabel;
	QPushButton *sesearchButton;
	QPushButton *closeButton;
	QGroupBox *optionButtonGroupBox;
	QGroupBox *optionButtonGroupBox2;
	QGroupBox *optionButtonGroupBox3;
	QGroupBox *createFirstExclusiveGroup();
	QGroupBox *createFirstExclusiveGroup2();
	QGroupBox *createFirstExclusiveGroup3();
	Q3TextEdit *textEdit1;

	QRadioButton *allowRadioButton;
	QRadioButton *neverallowRadioButton;
	QRadioButton *auditallowRadioButton;
	QRadioButton *dontauditRadioButton;
	QRadioButton *typeRadioButton;
	QRadioButton *role_allowRadioButton;
	QRadioButton *role_transRadioButton;
	QRadioButton *range_transRadioButton;
	QRadioButton *allRadioButton;

	QRadioButton *noneRadioButton;
	QRadioButton *sourceRadioButton;
	QRadioButton *targetRadioButton;
	QRadioButton *role_sourceRadioButton;
	QRadioButton *role_targetRadioButton;
	QRadioButton *classRadioButton;
	QRadioButton *permRadioButton;
	QRadioButton *boolRadioButton;

	QRadioButton *noneRadioButton2;
	QRadioButton *directRadioButton;
	QRadioButton *regexRadioButton;
	QRadioButton *linenumRadioButton;
	QRadioButton *semanticRadioButton;
	QRadioButton *show_condRadioButton;
	QRadioButton *helpRadioButton;
	QRadioButton *versionRadioButton;

        QLineEdit *sesearchEditLineEdit;
        QLineEdit *expressionEditLineEdit;
        QLineEdit *optionEditLineEdit;

	QHBoxLayout *mainLayout;
	QVBoxLayout *leftLayout;
	QVBoxLayout *leftupLayout;
	QVBoxLayout *leftdownLayout;
	QVBoxLayout *vbox;
	QVBoxLayout *vbox2;
	QVBoxLayout *vbox3;
	QVBoxLayout *rightLayout;

        QString sesearch_str_pp;
        QString sesearch_str_pp2;
        QString sesearch_str_pp3;
        QString sesearch_str_pp_str;
        QString expressionEditLineEdit_str;
        QString optionEditLineEdit_str;

};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/sesearch.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SESEARCH_H
#define SESEARCH_H

#include <QDialog>
#include <QLayout>
#include <QCheckBox>
#include <QLabel> 
#include <QButtonGroup>
#include <QPushButton>
#include <QGroupBox>
#include <QRadioButton>
#include <QHBoxLayout>
#include <QVBoxLayout>


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class SesearchProcess;

class Sesearch: public QDialog 
{
	Q_OBJECT
public:
	Sesearch(QWidget *parent = 0, const char *name = 0);
	SesearchProcess *sesearch_process;
public slots:
signals:
protected:
private slots:
	void sesearch_button_clicked();
public:
private:
	QLabel *sesearchLabel;
	QLabel *sesearch2Label;
	QLabel *expressionLabel;
	QLabel *optionLabel;
	QLabel *rule_typesLabel;
	QPushButton *sesearchButton;
	QPushButton *closeButton;
	QGroupBox *optionButtonGroupBox;
	QGroupBox *optionButtonGroupBox2;
	QGroupBox *optionButtonGroupBox3;
	QGroupBox *createFirstExclusiveGroup();
	QGroupBox *createFirstExclusiveGroup2();
	QGroupBox *createFirstExclusiveGroup3();
	QTextEdit *textEdit1;

	QRadioButton *allowRadioButton;
	QRadioButton *neverallowRadioButton;
	QRadioButton *auditallowRadioButton;
	QRadioButton *dontauditRadioButton;
	QRadioButton *typeRadioButton;
	QRadioButton *role_allowRadioButton;
	QRadioButton *role_transRadioButton;
	QRadioButton *range_transRadioButton;
	QRadioButton *allRadioButton;

	QRadioButton *noneRadioButton;
	QRadioButton *sourceRadioButton;
	QRadioButton *targetRadioButton;
	QRadioButton *role_sourceRadioButton;
	QRadioButton *role_targetRadioButton;
	QRadioButton *classRadioButton;
	QRadioButton *permRadioButton;
	QRadioButton *boolRadioButton;

	QRadioButton *noneRadioButton2;
	QRadioButton *directRadioButton;
	QRadioButton *regexRadioButton;
	QRadioButton *linenumRadioButton;
	QRadioButton *semanticRadioButton;
	QRadioButton *show_condRadioButton;
	QRadioButton *helpRadioButton;
	QRadioButton *versionRadioButton;

        QLineEdit *sesearchEditLineEdit;
        QLineEdit *expressionEditLineEdit;
        QLineEdit *optionEditLineEdit;

	QHBoxLayout *mainLayout;
	QVBoxLayout *leftLayout;
	QVBoxLayout *leftupLayout;
	QVBoxLayout *leftdownLayout;
	QVBoxLayout *vbox;
	QVBoxLayout *vbox2;
	QVBoxLayout *vbox3;
	QVBoxLayout *rightLayout;

        QString sesearch_str_pp;
        QString sesearch_str_pp2;
        QString sesearch_str_pp3;
        QString sesearch_str_pp_str;
        QString expressionEditLineEdit_str;
        QString optionEditLineEdit_str;

};

#endif
